@@ -8,5 +8,6 @@ var searchData=
   ['direction_5fvline_5',['DIRECTION_VLINE',['../lcd__draw_8h.html#a23a502f820e3da68a20d5abcfa0c6843',1,'lcd_draw.h']]],
   ['dma_5fmax_5ffifo_5fsize_6',['DMA_MAX_FIFO_SIZE',['../usbhs_8h.html#a74fb9f0009ae61530ac99e19744fc7f1',1,'usbhs.h']]],
   ['dma_5fqspi_5flli_7',['DMA_QSPI_LLI',['../qspi__dma_8c.html#afcf44cf0781ee50b2b939631f23abbfb',1,'qspi_dma.c']]],
-  ['dma_5fspi_5flli_8',['DMA_SPI_LLI',['../spi__dma_8c.html#a7ab960496ba3e3ebffb70d89f6b2d538',1,'spi_dma.c']]]
+  ['dma_5fspi_5flli_8',['DMA_SPI_LLI',['../spi__dma_8c.html#a7ab960496ba3e3ebffb70d89f6b2d538',1,'spi_dma.c']]],
+  ['drvmgr_5ffed_5fbf_9',['DRVMGR_FED_BF',['../drvmgr_8h.html#aa657b9168508708f9e54b8b7a71de627',1,'drvmgr.h']]]
 ];
