@@ -1,9 +1,9 @@
 var searchData=
 [
   ['page_2ec_0',['page.c',['../x86__64_2amd64_2start_2page_8c.html',1,'']]],
-  ['page_2eh_1',['page.h',['../bsps_2sparc64_2include_2arch_2mm_2page_8h.html',1,'(Global Namespace)'],['../bsps_2sparc64_2include_2arch_2mm_2sun4u_2page_8h.html',1,'(Global Namespace)']]],
+  ['page_2eh_1',['page.h',['../bsps_2sparc64_2include_2arch_2mm_2sun4u_2page_8h.html',1,'(Global Namespace)'],['../bsps_2sparc64_2include_2arch_2mm_2page_8h.html',1,'(Global Namespace)']]],
   ['panic_2ec_2',['panic.c',['../panic_8c.html',1,'']]],
-  ['paravirt_2eh_3',['paravirt.h',['../powerpc_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)'],['../i386_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)'],['../arm_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)'],['../aarch64_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)']]],
+  ['paravirt_2eh_3',['paravirt.h',['../aarch64_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)'],['../arm_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)'],['../i386_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)'],['../powerpc_2include_2rtems_2score_2paravirt_8h.html',1,'(Global Namespace)']]],
   ['part_2ec_4',['part.c',['../part_8c.html',1,'']]],
   ['part_2eh_5',['part.h',['../part_8h.html',1,'']]],
   ['partcreate_2ec_6',['partcreate.c',['../partcreate_8c.html',1,'']]],
@@ -22,13 +22,13 @@ var searchData=
   ['pbarrierinit_2ec_19',['pbarrierinit.c',['../pbarrierinit_8c.html',1,'']]],
   ['pbarrierwait_2ec_20',['pbarrierwait.c',['../pbarrierwait_8c.html',1,'']]],
   ['pci_2ec_21',['pci.c',['../mips_2malta_2pci_2pci_8c.html',1,'']]],
-  ['pci_2eh_22',['pci.h',['../cpukit_2include_2pci_8h.html',1,'(Global Namespace)'],['../cpukit_2include_2rtems_2pci_8h.html',1,'(Global Namespace)'],['../bsps_2mips_2malta_2include_2bsp_2pci_8h.html',1,'(Global Namespace)']]],
+  ['pci_2eh_22',['pci.h',['../cpukit_2include_2rtems_2pci_8h.html',1,'(Global Namespace)'],['../cpukit_2include_2pci_8h.html',1,'(Global Namespace)'],['../bsps_2mips_2malta_2include_2bsp_2pci_8h.html',1,'(Global Namespace)']]],
   ['pci_5fbus_2eh_23',['pci_bus.h',['../pci__bus_8h.html',1,'']]],
   ['pci_5ffind_5fdevice_2ec_24',['pci_find_device.c',['../pci__find__device_8c.html',1,'']]],
   ['pci_5fio_2ec_25',['pci_io.c',['../pci__io_8c.html',1,'']]],
   ['pcibios_2ec_26',['pcibios.c',['../pcibios_8c.html',1,'']]],
   ['percpu_2ec_27',['percpu.c',['../percpu_8c.html',1,'']]],
-  ['percpu_2eh_28',['percpu.h',['../confdefs_2percpu_8h.html',1,'(Global Namespace)'],['../score_2percpu_8h.html',1,'(Global Namespace)']]],
+  ['percpu_2eh_28',['percpu.h',['../score_2percpu_8h.html',1,'(Global Namespace)'],['../confdefs_2percpu_8h.html',1,'(Global Namespace)']]],
   ['percpuasm_2ec_29',['percpuasm.c',['../percpuasm_8c.html',1,'']]],
   ['percpudata_2ec_30',['percpudata.c',['../percpudata_8c.html',1,'']]],
   ['percpudata_2eh_31',['percpudata.h',['../percpudata_8h.html',1,'']]],
@@ -73,8 +73,8 @@ var searchData=
   ['printk_2dsupport_2ec_70',['printk-support.c',['../tms570_2console_2printk-support_8c.html',1,'']]],
   ['printk_2ec_71',['printk.c',['../printk_8c.html',1,'']]],
   ['printk_5fplugin_2ec_72',['printk_plugin.c',['../printk__plugin_8c.html',1,'']]],
-  ['printk_5fsupport_2ec_73',['printk_support.c',['../sparc_2leon3_2console_2printk__support_8c.html',1,'(Global Namespace)'],['../mips_2malta_2console_2printk__support_8c.html',1,'(Global Namespace)']]],
-  ['priority_2eh_74',['priority.h',['../rtems_2score_2priority_8h.html',1,'(Global Namespace)'],['../sys_2priority_8h.html',1,'(Global Namespace)']]],
+  ['printk_5fsupport_2ec_73',['printk_support.c',['../mips_2malta_2console_2printk__support_8c.html',1,'(Global Namespace)'],['../sparc_2leon3_2console_2printk__support_8c.html',1,'(Global Namespace)']]],
+  ['priority_2eh_74',['priority.h',['../sys_2priority_8h.html',1,'(Global Namespace)'],['../rtems_2score_2priority_8h.html',1,'(Global Namespace)']]],
   ['prioritybitmap_2eh_75',['prioritybitmap.h',['../prioritybitmap_8h.html',1,'']]],
   ['prioritybitmapimpl_2eh_76',['prioritybitmapimpl.h',['../prioritybitmapimpl_8h.html',1,'']]],
   ['priorityimpl_2eh_77',['priorityimpl.h',['../posix_2priorityimpl_8h.html',1,'(Global Namespace)'],['../score_2priorityimpl_8h.html',1,'(Global Namespace)']]],
@@ -82,7 +82,7 @@ var searchData=
   ['processormask_2eh_79',['processormask.h',['../processormask_8h.html',1,'']]],
   ['processormaskcopy_2ec_80',['processormaskcopy.c',['../processormaskcopy_8c.html',1,'']]],
   ['processormaskimpl_2eh_81',['processormaskimpl.h',['../processormaskimpl_8h.html',1,'']]],
-  ['profiling_2eh_82',['profiling.h',['../score_2profiling_8h.html',1,'(Global Namespace)'],['../profiling_8h.html',1,'(Global Namespace)']]],
+  ['profiling_2eh_82',['profiling.h',['../profiling_8h.html',1,'(Global Namespace)'],['../score_2profiling_8h.html',1,'(Global Namespace)']]],
   ['profilingisrentryexit_2ec_83',['profilingisrentryexit.c',['../profilingisrentryexit_8c.html',1,'']]],
   ['profilingiterate_2ec_84',['profilingiterate.c',['../profilingiterate_8c.html',1,'']]],
   ['profilingreportxml_2ec_85',['profilingreportxml.c',['../profilingreportxml_8c.html',1,'']]],
