@@ -105,14 +105,14 @@ var searchData=
   ['regionprocessqueue_2ec_102',['regionprocessqueue.c',['../regionprocessqueue_8c.html',1,'']]],
   ['regionresizesegment_2ec_103',['regionresizesegment.c',['../regionresizesegment_8c.html',1,'']]],
   ['regionreturnsegment_2ec_104',['regionreturnsegment.c',['../regionreturnsegment_8c.html',1,'']]],
-  ['registers_2eh_105',['registers.h',['../powerpc_2include_2rtems_2powerpc_2registers_8h.html',1,'(Global Namespace)'],['../i386_2include_2rtems_2score_2registers_8h.html',1,'(Global Namespace)']]],
+  ['registers_2eh_105',['registers.h',['../i386_2include_2rtems_2score_2registers_8h.html',1,'(Global Namespace)'],['../powerpc_2include_2rtems_2powerpc_2registers_8h.html',1,'(Global Namespace)']]],
   ['regs_2dedma_2eh_106',['regs-edma.h',['../powerpc_2mpc55xxevb_2include_2mpc55xx_2regs-edma_8h.html',1,'(Global Namespace)'],['../include_2fsl_2regs-edma_8h.html',1,'(Global Namespace)']]],
   ['regs_2dmmu_2eh_107',['regs-mmu.h',['../regs-mmu_8h.html',1,'']]],
   ['regs_2eh_108',['regs.h',['../powerpc_2mpc55xxevb_2include_2mpc55xx_2regs_8h.html',1,'(Global Namespace)'],['../mips_2include_2bsp_2regs_8h.html',1,'(Global Namespace)']]],
   ['regulator_2ec_109',['regulator.c',['../regulator_8c.html',1,'']]],
   ['regulator_2eh_110',['regulator.h',['../regulator_8h.html',1,'']]],
   ['regulatorimpl_2eh_111',['regulatorimpl.h',['../regulatorimpl_8h.html',1,'']]],
-  ['restart_2ec_112',['restart.c',['../arm_2lpc32xx_2start_2restart_8c.html',1,'(Global Namespace)'],['../arm_2lpc24xx_2start_2restart_8c.html',1,'(Global Namespace)'],['../arm_2lpc176x_2start_2restart_8c.html',1,'(Global Namespace)']]],
+  ['restart_2ec_112',['restart.c',['../arm_2lpc24xx_2start_2restart_8c.html',1,'(Global Namespace)'],['../arm_2lpc32xx_2start_2restart_8c.html',1,'(Global Namespace)'],['../arm_2lpc176x_2start_2restart_8c.html',1,'(Global Namespace)']]],
   ['ringbuf_2eh_113',['ringbuf.h',['../ringbuf_8h.html',1,'']]],
   ['riscv_2dutility_2eh_114',['riscv-utility.h',['../riscv-utility_8h.html',1,'']]],
   ['riscv_2eh_115',['riscv.h',['../cpukit_2score_2cpu_2riscv_2include_2rtems_2score_2riscv_8h.html',1,'']]],
@@ -122,9 +122,9 @@ var searchData=
   ['rpi_2dgpio_2ec_119',['rpi-gpio.c',['../rpi-gpio_8c.html',1,'']]],
   ['rpi_2dgpio_2eh_120',['rpi-gpio.h',['../arm_2raspberrypi_2include_2bsp_2rpi-gpio_8h.html',1,'(Global Namespace)'],['../aarch64_2raspberrypi_2include_2bsp_2rpi-gpio_8h.html',1,'(Global Namespace)']]],
   ['rstc_2ec_121',['rstc.c',['../rstc_8c.html',1,'']]],
-  ['rtc_2dconfig_2ec_122',['rtc-config.c',['../powerpc_2qoriq_2rtc_2rtc-config_8c.html',1,'(Global Namespace)'],['../arm_2lpc176x_2rtc_2rtc-config_8c.html',1,'(Global Namespace)'],['../arm_2lpc24xx_2rtc_2rtc-config_8c.html',1,'(Global Namespace)'],['../arm_2lpc32xx_2rtc_2rtc-config_8c.html',1,'(Global Namespace)']]],
-  ['rtc_2ec_123',['rtc.c',['../arm_2altera-cyclone-v_2rtc_2rtc_8c.html',1,'(Global Namespace)'],['../arm_2atsam_2contrib_2libraries_2libchip_2source_2rtc_8c.html',1,'(Global Namespace)'],['../arm_2beagle_2rtc_2rtc_8c.html',1,'(Global Namespace)']]],
-  ['rtc_2eh_124',['rtc.h',['../cpukit_2include_2rtems_2rtc_8h.html',1,'(Global Namespace)'],['../bsps_2arm_2atsam_2include_2libchip_2include_2rtc_8h.html',1,'(Global Namespace)']]],
+  ['rtc_2dconfig_2ec_122',['rtc-config.c',['../arm_2lpc176x_2rtc_2rtc-config_8c.html',1,'(Global Namespace)'],['../arm_2lpc24xx_2rtc_2rtc-config_8c.html',1,'(Global Namespace)'],['../arm_2lpc32xx_2rtc_2rtc-config_8c.html',1,'(Global Namespace)'],['../powerpc_2qoriq_2rtc_2rtc-config_8c.html',1,'(Global Namespace)']]],
+  ['rtc_2ec_123',['rtc.c',['../arm_2beagle_2rtc_2rtc_8c.html',1,'(Global Namespace)'],['../arm_2atsam_2contrib_2libraries_2libchip_2source_2rtc_8c.html',1,'(Global Namespace)'],['../arm_2altera-cyclone-v_2rtc_2rtc_8c.html',1,'(Global Namespace)']]],
+  ['rtc_2eh_124',['rtc.h',['../bsps_2arm_2atsam_2include_2libchip_2include_2rtc_8h.html',1,'(Global Namespace)'],['../cpukit_2include_2rtems_2rtc_8h.html',1,'(Global Namespace)']]],
   ['rtc_5fcalib_2eh_125',['rtc_calib.h',['../rtc__calib_8h.html',1,'']]],
   ['rtd316_2ec_126',['rtd316.c',['../rtd316_8c.html',1,'']]],
   ['rtd316_2eh_127',['rtd316.h',['../rtd316_8h.html',1,'']]],
