@@ -11,7 +11,7 @@ var searchData=
   ['uart_2dprobe_2d2_2ec_8',['uart-probe-2.c',['../uart-probe-2_8c.html',1,'']]],
   ['uart_2dprobe_2d3_2ec_9',['uart-probe-3.c',['../uart-probe-3_8c.html',1,'']]],
   ['uart_2ec_10',['uart.c',['../arm_2atsam_2contrib_2libraries_2libchip_2source_2uart_8c.html',1,'(Global Namespace)'],['../or1k_2generic__or1k_2console_2uart_8c.html',1,'(Global Namespace)']]],
-  ['uart_2eh_11',['uart.h',['../arm_2edb7312_2include_2uart_8h.html',1,'(Global Namespace)'],['../arm_2lm3s69xx_2include_2bsp_2uart_8h.html',1,'(Global Namespace)'],['../i386_2include_2uart_8h.html',1,'(Global Namespace)'],['../lm32_2shared_2console_2uart_8h.html',1,'(Global Namespace)'],['../lm32_2shared_2milkymist__console_2uart_8h.html',1,'(Global Namespace)'],['../or1k_2generic__or1k_2include_2bsp_2uart_8h.html',1,'(Global Namespace)']]],
+  ['uart_2eh_11',['uart.h',['../lm32_2shared_2console_2uart_8h.html',1,'(Global Namespace)'],['../or1k_2generic__or1k_2include_2bsp_2uart_8h.html',1,'(Global Namespace)'],['../lm32_2shared_2milkymist__console_2uart_8h.html',1,'(Global Namespace)'],['../arm_2edb7312_2include_2uart_8h.html',1,'(Global Namespace)'],['../arm_2lm3s69xx_2include_2bsp_2uart_8h.html',1,'(Global Namespace)'],['../i386_2include_2uart_8h.html',1,'(Global Namespace)']]],
   ['uart_5fdma_2ec_12',['uart_dma.c',['../uart__dma_8c.html',1,'']]],
   ['uart_5fdma_2eh_13',['uart_dma.h',['../uart__dma_8h.html',1,'']]],
   ['uartlite_2ec_14',['uartlite.c',['../uartlite_8c.html',1,'']]],
@@ -23,7 +23,7 @@ var searchData=
   ['untar_2ec_20',['untar.c',['../untar_8c.html',1,'']]],
   ['untar_2eh_21',['untar.h',['../untar_8h.html',1,'']]],
   ['usart_2ec_22',['usart.c',['../atsam_2contrib_2libraries_2libchip_2source_2usart_8c.html',1,'']]],
-  ['usart_2eh_23',['usart.h',['../raspberrypi_2include_2bsp_2usart_8h.html',1,'(Global Namespace)'],['../stm32f4_2include_2bsp_2usart_8h.html',1,'(Global Namespace)'],['../atsam_2include_2libchip_2include_2usart_8h.html',1,'(Global Namespace)']]],
+  ['usart_2eh_23',['usart.h',['../stm32f4_2include_2bsp_2usart_8h.html',1,'(Global Namespace)'],['../raspberrypi_2include_2bsp_2usart_8h.html',1,'(Global Namespace)'],['../atsam_2include_2libchip_2include_2usart_8h.html',1,'(Global Namespace)']]],
   ['usart_5fdma_2ec_24',['usart_dma.c',['../usart__dma_8c.html',1,'']]],
   ['usart_5fdma_2eh_25',['usart_dma.h',['../usart__dma_8h.html',1,'']]],
   ['usbhs_2eh_26',['usbhs.h',['../usbhs_8h.html',1,'']]],
