@@ -14,7 +14,7 @@ var searchData=
   ['legacy_2dconsole_2dselect_2ec_11',['legacy-console-select.c',['../legacy-console-select_8c.html',1,'']]],
   ['legacy_2dconsole_2ec_12',['legacy-console.c',['../legacy-console_8c.html',1,'']]],
   ['legacy_2dconsole_2eh_13',['legacy-console.h',['../legacy-console_8h.html',1,'']]],
-  ['leon_2eh_14',['leon.h',['../leon3_2include_2leon_8h.html',1,'(Global Namespace)'],['../leon2_2include_2leon_8h.html',1,'(Global Namespace)']]],
+  ['leon_2eh_14',['leon.h',['../leon2_2include_2leon_8h.html',1,'(Global Namespace)'],['../leon3_2include_2leon_8h.html',1,'(Global Namespace)']]],
   ['leon2_5famba_5fbus_2eh_15',['leon2_amba_bus.h',['../leon2__amba__bus_8h.html',1,'']]],
   ['leon3_2eh_16',['leon3.h',['../leon3_8h.html',1,'']]],
   ['libatomic_2ec_17',['libatomic.c',['../libatomic_8c.html',1,'']]],
@@ -28,7 +28,7 @@ var searchData=
   ['libiozeroiops_2ec_25',['libiozeroiops.c',['../libiozeroiops_8c.html',1,'']]],
   ['libpci_2eh_26',['libpci.h',['../libpci_8h.html',1,'']]],
   ['link_2ec_27',['link.c',['../link_8c.html',1,'']]],
-  ['linker_2dsymbols_2darch_2eh_28',['linker-symbols-arch.h',['../riscv_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../powerpc_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../or1k_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../microblaze_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../m68k_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../arm_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../aarch64_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)']]],
+  ['linker_2dsymbols_2darch_2eh_28',['linker-symbols-arch.h',['../aarch64_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../riscv_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../powerpc_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../or1k_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../microblaze_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../m68k_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)'],['../arm_2include_2bsp_2linker-symbols-arch_8h.html',1,'(Global Namespace)']]],
   ['linker_2dsymbols_2eh_29',['linker-symbols.h',['../linker-symbols_8h.html',1,'']]],
   ['linkersets_2eh_30',['linkersets.h',['../linkersets_8h.html',1,'']]],
   ['lio_5flistio_2ec_31',['lio_listio.c',['../lio__listio_8c.html',1,'']]],
